@@ -13,24 +13,25 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 import abc
-from influxdb import InfluxDBClient
+import influxdb
 from oslo_config import cfg
 import six
 
-from repositories.abstract_repository import AbstractRepository
+from monasca_persister.repositories import abstract_repository
 
 
 @six.add_metaclass(abc.ABCMeta)
-class AbstractInfluxdbRepository(AbstractRepository):
+class AbstractInfluxdbRepository(abstract_repository.AbstractRepository):
 
     def __init__(self):
         super(AbstractInfluxdbRepository, self).__init__()
         self.conf = cfg.CONF
-        self._influxdb_client = InfluxDBClient(self.conf.influxdb.ip_address,
-                                               self.conf.influxdb.port,
-                                               self.conf.influxdb.user,
-                                               self.conf.influxdb.password,
-                                               self.conf.influxdb.database_name)
+        self._influxdb_client = influxdb.InfluxDBClient(
+            self.conf.influxdb.ip_address,
+            self.conf.influxdb.port,
+            self.conf.influxdb.user,
+            self.conf.influxdb.password,
+            self.conf.influxdb.database_name)
 
     def write_batch(self, data_points):
         self._influxdb_client.write_points(data_points, 'ms')
